3.37.17 (2023-07-10)
====================
👷 Bug fixes
------------

- migration: allow to drop a cube even if it's a dependency (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/774)

3.37.16 (2023-06-07)
====================
👷 Bug fixes
------------

- pyramid: allows to use None for timeout, max_age and reissue_time options

3.37.15 (2023-03-24)
====================
👷 Bug fixes
------------

- testlib: define properly a generate_tzdatetime method with timezone (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/716)

🤖 Continuous integration
-------------------------

- avoid launching duplicated migractions tests
- clean CI of unused jobs
- disable can-i-merge
- don't wait for tests to start QA jobs
- smoke_test: add timeout to request to avoid hanging up for too long
- smoke_test: handle ConnectionError situation
- test-cube-skeleton: ensure we use the same python version for smoke test than py3-* tests

3.37.14 (2023-03-07)
====================
👷 Bug fixes
------------

- rdf: https instead of http for schema.org
- sphinx-theme 1.0 breaks doc build
- make sure we only install yapps2-logilab by updating depencies
- tried to format a string while missing one formatting argument

3.37.13 (2023-01-27)
====================
🎉 New features
---------------

- misc: allow to disable or not constraint check on fast drop script

3.37.12 (2023-01-17)
====================
🎉 New features
---------------

- skeleton: remove format=pylint option from tox because it's better without it

3.37.11 (2023-01-12)
====================
👷 Bug fixes
------------

- avoid risking new cubes to install pre-release version of black
- formrenderers: use UStringIO instead of list to keep the same api as self.w (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/597)
- schema_exporters: Add missing description field for relations (e.g `in_state`) to schema exporter

3.37.10 (2022-12-05)
====================
🎉 New features
---------------

- schema: Export relations options on the schema

👷 Bug fixes
------------

- schema_exporters: Add missing description field for relations (e.g `in_state`) to schema exporter

3.37.9 (2022-11-15)
===================
👷 Bug fixes
------------

- hook: correct a typo, self.warn doesn't exist

3.37.8 (2022-10-04)
===================
👷 Bug fixes
------------

- attr: when an entity is not existing always return None when fetching its attributes (#599)
- web.views: escape text from the undohistory view (#598)

🤷 Various changes
------------------

- delete unused translations from \*.po files (#600)
- skeleton: add `long_description_content_type` in setup.py

3.37.7 (2022-09-22)
===================
👷 Bug fixes
------------

- startup_views: raise AuthenticationError if anon access is disabled on
  StartupView (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/595)

3.37.6 (2022-09-14)
===================
👷 Bug fixes
------------

- bookmark: do not escape the xaddrelation view from ajaxedit module

3.37.5 (2022-08-30)
===================
👷 Bug fixes
------------

- pyramid: Redirect to the wanted URL after a successfully loggedin (to #584)
- xss: Ensure to use the xml_escape method on entity attributes
- perf: Restore initial performances by removing the uneccessary join

3.37.4 (2022-07-21)
===================
👷 Bug fixes
------------

- schema_exporters: handle symmetrical relation in schema export. (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/568)

🤷 Various changes
------------------

- feat(markdown)!: update Mardown version to 3.4 and rewrite urlize extension (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/569)

3.37.3 (2022-07-13)
===================

👷 Bug fixes
------------

- htmlwidgets: BoxLink rendering is broken

3.37.2 (2022-06-03)
===================
👷 Bug fixes
------------

- pyramid: adapt TestApp.put_json method to CSRF

3.37.1 (2022-06-01)
===================
🎉 New features
---------------

- pkg: upgrade version of waitress to 2.1.1 or more, for security reason. (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/543)

👷 Bug fixes
------------

- base64.decodestring is deprecated and has been removed
- pyramid tests: adapt TestApp.post_json method to CSRF
- pyramid tests: try to get "/login" if "/" is forbidden

3.37.0 (2022-03-31)
===================
Breaking changes
----------------

- ``cubicweb.web.BaseWebConfiguration``
  and ``cubicweb.web.WebConfigurationBase``
  have been merged into cubicweb.web.WebConfiguration
- ``cubicweb.web.CubicWebPyramidConfiguration`` had been removed
- you can nomore use -c option when creating a CW instance, since
  there is now only one kind of configuration: all-in-one.conf

🎉 New features
---------------

- add attributes constraints in exported schema
- depends on `yams 0.48 <https://forge.extranet.logilab.fr/open-source/yams/-/blob/branch/default/CHANGELOG.md#version-0480-2022-03-25>`_
- doc: mostly add links of issues

👷 Bug fixes
------------

- unittest_devctl: give all debugging informations

🤖 Continuous integration
-------------------------

- use templates

🤷 Various changes
------------------

- refactor!: merge ``BaseWebConfiguration`` into ``WebConfiguration``
- refactor!: remove ``-c`` option to ``cubicweb-ctl create``
  to only use all-in-one
- refactor!: remove unused ``CubicWebPyramidConfiguration``
